/****************************************/
/*                                      */
/* Beispielprogramm Linien-Folger       */
/* Autor: I. Boersch, 02/2004           */
/*                                      */
/****************************************/

#include <stdio.h>			   /* Einbinden der Headerdateien */
#include <regc515c.h>		   /* benoetigter Bibliothek      */
#include <stub.h>

#define O_LINKS  0             /* Anschlussports der drei Optokoppler */
#define O_MITTE  1
#define O_RECHTS 2

#define M_LINKS  3             /* Anschlussports der beiden Motore */
#define M_RECHTS 2

#define SCHNELL 10             /* Geschwindigkeitsdefinitionen */
#define MITTEL 7
#define LANGSAM 1

#define MAX_NO_BLACK 180       /* maximale Fahrzeit ohne Linie */
#define schwarz(x) (x > 150)   /* Schwellwertueberpruefung */


/****************************/
/* Das eigentliche Programm */
/****************************/
void AksenMain(void)
{
    unsigned int no_black = 0;
    unsigned char o_links, o_mitte, o_rechts;

    led(3,1);                                   /* Optokoppler an */
    led(1,1);									

    motor_richtung(M_LINKS,1);                  /* Motoren einschalten */
    motor_richtung(M_RECHTS,1);					

    do                                          /* Eine Endlosschleife */
    {
		o_links  = analog(O_LINKS);				/* Sonsorwerte auslesen */
		o_rechts = analog(O_MITTE);				
		o_mitte  = analog(O_RECHTS);			

        lcd_cls();								/* LCD loeschen */
        lcd_setxy(0,0);							/* LCD-Cursor positioieren */
        lcd_puts("L="); lcd_ubyte(o_links);     /* Statusinform. ausgeben  */
        lcd_puts("M="); lcd_ubyte(o_mitte);     
        lcd_puts("R="); lcd_ubyte(o_rechts);    

        if (schwarz(o_rechts))					/* rechter Optokoppler auf der Linie ? */
        {
            no_black = 0;
            motor_pwm(M_RECHTS,LANGSAM);
            motor_pwm(M_LINKS,MITTEL);
        }
        else if (schwarz(o_links))				/* linker Optokoppler auf der Linie ? */
        {
            no_black = 0;
            motor_pwm(M_RECHTS,MITTEL);
            motor_pwm(M_LINKS,LANGSAM);
        }
        else if (schwarz(o_mitte))				/* mittlerer Optokoppler auf der Linie ? */
        {
            no_black = 0;
            motor_pwm(M_RECHTS,SCHNELL);
            motor_pwm(M_LINKS,SCHNELL);
        }
        else if (no_black > MAX_NO_BLACK)		/* Linie verloren ? */
        {
            motor_pwm(M_RECHTS,0);
            motor_pwm(M_LINKS,0);
            lcd_puts("Linie verloren \n stop");
            while(1);
        }
        else
        {
            no_black++;
        }

    } while(1);
}
